@@ -8,12 +8,21 @@
     :copyright: Conceptual Vision Consulting LLC 2018-2019, see AUTHORS for more details.
     :license: MIT, see LICENSE for more details.
 """
+from abc import ABC
+from typing import List, Optional, TypeVar
 
-class IFilteredReader:
+from pip_services3_commons.data import SortParams, FilterParams
+
+T = TypeVar('T')  # Declare type variable
+
+
+class IFilteredReader(ABC):
     """
     Interface for data processing components that can retrieve a list of data items by filter.
     """
-    def get_list_by_filter(self, correlation_id, filter, sort = None):
+
+    def get_list_by_filter(self, correlation_id: Optional[str], filter: Optional[FilterParams],
+                           sort: Optional[SortParams] = None) -> List[T]:
         """
         Gets a list of data items using filter parameters.
 
@@ -21,6 +30,8 @@ class IFilteredReader:
 
         :param filter: (optional) filter parameters
 
+        :param sort: (optional) sort parameters
+
         :param paging: (optional) paging parameters
 
         :return: list of items
