@@ -8,12 +8,21 @@
     :copyright: Conceptual Vision Consulting LLC 2018-2019, see AUTHORS for more details.
     :license: MIT, see LICENSE for more details.
 """
+from abc import ABC
+from typing import List, Optional, TypeVar
 
-class IQuerableReader:
+from pip_services3_commons.data import SortParams
+
+T = TypeVar('T')  # Declare type variable
+
+
+class IQuerableReader(ABC):
     """
     Interface for data processing components that can query a list of data items.
     """
-    def get_list_by_query(self, correlation_id, query, sort = None):
+
+    def get_list_by_query(self, correlation_id: Optional[str], query: Optional[str],
+                          sort: Optional[SortParams] = None) -> List[T]:
         """
         Gets a list of data items using a query string.
 
