@@ -8,12 +8,17 @@
     :copyright: Conceptual Vision Consulting LLC 2018-2019, see AUTHORS for more details.
     :license: MIT, see LICENSE for more details.
 """
+from typing import List, Optional, TypeVar
+
+T = TypeVar('T')  # Declare type variable
+
 
 class ISaver:
     """
     Interface for data processing components that save data items.
     """
-    def save(self, correlation_id, items):
+
+    def save(self, correlation_id: Optional[str], items: List[T]):
         """
         Saves given data items.
 
